Description Usage Arguments Value Author(s) Examples
This function analyses the coronavirus proportional abundance distribution (CPAD)
1 | analyse_CPAD(propab.matrix, propab.df, sumCases, avCases, saveplots = TRUE)
|
propab.matrix: |
dataframe. The global active cases/country population (proprtional abundance) by country and day. |
propab.df: |
dataframe. The proportional abundance dataframe of htree columns: |
sumCases: |
numeric vector. The daily sum of active SARS-CoV-2 cases; its length must be equal that the temporal slices present in |
avCases: |
numeric vector. The daily average of active SARS-CoV-2 cases; its length must be equal that the temporal slices present in |
saveplots: |
|
The function returns the CPAD dataframe to your Global Environment with the corresponding statistics for each day. If saveplots is TRUE, the plots folder is created in your wd, containing different folder with plots.
Simon P Castillo spcastil@uc.cl.
1 | analyse_CPAD(propab.matrix=propab_matrix, propab.df=propab_df, sumCases=sumCases, avCases=avCases, saveplots= TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.