plot_ratioCountries: Plot the fraction of countries with active SARS-CoV-2 vs sum...

Description Usage Arguments Value Author(s) Examples

View source: R/plot_ratioCountries.R

Description

This function plots the relations between the fraction of countries with active SARS-CoV-2 vs sum #SARS-CoV-2, E|#SARS-CoV-2|, and E|prop ab|.

Usage

1
plot_ratioCountries(CPAD, disease, saveplot = TRUE, saveplot.ext = ".png")

Arguments

CPAD:

dataframe. The dataframe returned by analyse_CPAD.

disease:

*character*. Name of the disease. It will apply if the plots are saved.

saveplots:

TRUE or FALSE. Save the plots in your wd.Default TRUE.

saveplots.ext:

character. The extension for the saved figures admitted by ggsave (e.g., ".png", ".svg").Default ".png".

Value

This function return to your global environment an object list named plotratioCountries with the plot(s) created. Also, if saveplot is TRUE, a folder named betaplots in the folder plots is created in your wd.

Author(s)

Simon P Castillo spcastil@uc.cl.

Examples

1
plot_ratioCountries(CPAD, saveplot=TRUE, saveplot.ext= ".png")

simonpcastillo/CPAD documentation built on Dec. 31, 2020, 7:27 a.m.