Description Usage Arguments Value Author(s) Examples
View source: R/plot_ratioCountries.R
This function plots the relations between the fraction of countries with active SARS-CoV-2 vs sum #SARS-CoV-2, E|#SARS-CoV-2|, and E|prop ab|.
1 | plot_ratioCountries(CPAD, disease, saveplot = TRUE, saveplot.ext = ".png")
|
CPAD: |
dataframe. The dataframe returned by |
disease: |
*character*. Name of the disease. It will apply if the plots are saved. |
saveplots: |
|
saveplots.ext: |
character. The extension for the saved figures admitted by |
This function return to your global environment an object list named plotratioCountries with the plot(s) created. Also, if saveplot is TRUE, a folder named betaplots in the folder plots is created in your wd.
Simon P Castillo spcastil@uc.cl.
1 | plot_ratioCountries(CPAD, saveplot=TRUE, saveplot.ext= ".png")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.